==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/forms/lang/el.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'el', {
	button: {
		title: 'Ιδιότητες Κουμπιού',
		text: 'Κείμενο (Τιμή)',
		type: 'Τύπος',
		typeBtn: 'Κουμπί',
		typeSbm: 'Υποβολή',
		typeRst: 'Επαναφορά'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Ιδιότητες Κουτιού Επιλογής',
		radioTitle: 'Ιδιότητες Κουμπιού Επιλογής',
		value: 'Τιμή',
		selected: 'Επιλεγμένο',
		required: 'Απαιτείται'
	},
	form: {
		title: 'Ιδιότητες Φόρμας',
		menu: 'Ιδιότητες Φόρμας',
		action: 'Ενέργεια',
		method: 'Μέθοδος',
		encoding: 'Κωδικοποίηση'
	},
	hidden: {
		title: 'Ιδιότητες Κρυφού Πεδίου',
		name: 'Όνομα',
		value: 'Τιμή'
	},
	select: {
		title: 'Ιδιότητες Πεδίου Επιλογής',
		selectInfo: 'Πληροφορίες Πεδίου Επιλογής',
		opAvail: 'Διαθέσιμες Επιλογές',
		value: 'Τιμή',
		size: 'Μέγεθος',
		lines: 'γραμμές',
		chkMulti: 'Να επιτρέπονται οι πολλαπλές επιλογές',
		required: 'Required', // MISSING
		opText: 'Κείμενο',
		opValue: 'Τιμή',
		btnAdd: 'Προσθήκη',
		btnModify: 'Τροποποίηση',
		btnUp: 'Πάνω',
		btnDown: 'Κάτω',
		btnSetValue: 'Θέση ως προεπιλογή',
		btnDelete: 'Διαγραφή'
	},
	textarea: {
		title: 'Ιδιότητες Περιοχής Κειμένου',
		cols: 'Στήλες',
		rows: 'Σειρές'
	},
	textfield: {
		title: 'Ιδιότητες Πεδίου Κειμένου',
		name: 'Όνομα',
		value: 'Τιμή',
		charWidth: 'Πλάτος Χαρακτήρων',
		maxChars: 'Μέγιστοι χαρακτήρες',
		required: 'Required', // MISSING
		type: 'Τύπος',
		typeText: 'Κείμενο',
		typePass: 'Κωδικός',
		typeEmail: 'Email',
		typeSearch: 'Αναζήτηση',
		typeTel: 'Αριθμός Τηλεφώνου',
		typeUrl: 'URL'
	}
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/forms/lang/el.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'forms', 'el', {
	button: {
		title: 'Ιδιότητες Κουμπιού',
		text: 'Κείμενο (Τιμή)',
		type: 'Τύπος',
		typeBtn: 'Κουμπί',
		typeSbm: 'Υποβολή',
		typeRst: 'Επαναφορά'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Ιδιότητες Κουτιού Επιλογής',
		radioTitle: 'Ιδιότητες Κουμπιού Επιλογής',
		value: 'Τιμή',
		selected: 'Επιλεγμένο',
		required: 'Απαιτείται'
	},
	form: {
		title: 'Ιδιότητες Φόρμας',
		menu: 'Ιδιότητες Φόρμας',
		action: 'Ενέργεια',
		method: 'Μέθοδος',
		encoding: 'Κωδικοποίηση'
	},
	hidden: {
		title: 'Ιδιότητες Κρυφού Πεδίου',
		name: 'Όνομα',
		value: 'Τιμή'
	},
	select: {
		title: 'Ιδιότητες Πεδίου Επιλογής',
		selectInfo: 'Πληροφορίες Πεδίου Επιλογής',
		opAvail: 'Διαθέσιμες Επιλογές',
		value: 'Τιμή',
		size: 'Μέγεθος',
		lines: 'γραμμές',
		chkMulti: 'Να επιτρέπονται οι πολλαπλές επιλογές',
		required: 'Απαιτείται',
		opText: 'Κείμενο',
		opValue: 'Τιμή',
		btnAdd: 'Προσθήκη',
		btnModify: 'Τροποποίηση',
		btnUp: 'Πάνω',
		btnDown: 'Κάτω',
		btnSetValue: 'Θέση ως προεπιλογή',
		btnDelete: 'Διαγραφή'
	},
	textarea: {
		title: 'Ιδιότητες Περιοχής Κειμένου',
		cols: 'Στήλες',
		rows: 'Σειρές'
	},
	textfield: {
		title: 'Ιδιότητες Πεδίου Κειμένου',
		name: 'Όνομα',
		value: 'Τιμή',
		charWidth: 'Πλάτος Χαρακτήρων',
		maxChars: 'Μέγιστοι χαρακτήρες',
		required: 'Απαιτείται',
		type: 'Τύπος',
		typeText: 'Κείμενο',
		typePass: 'Κωδικός',
		typeEmail: 'Email',
		typeSearch: 'Αναζήτηση',
		typeTel: 'Αριθμός Τηλεφώνου',
		typeUrl: 'URL'
	}
} );
